[![Travis](https://img.shields.io/travis/openspending/os-package-registry.svg)](https://travis-ci.org/openspending/os-package-registry)
[![Coveralls](http://img.shields.io/coveralls/openspending/os-package-registry/master.svg)](https://coveralls.io/r/openspending/os-package-registry)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/os-package-registry.svg)](https://pypi.org/project/os-package-registry/)

# os-package-registry

Manage and query a registry of packages on an ElasticSearch instance.


## Tests

Tests require an Elasticsearch instance running on port 9200. Tests can be run with tox:

```sh
$ tox
```
